@@ -8,8 +8,8 @@
 
 #include "akonadi_notes_debug.h"
 #include <KLocalizedString>
+#include <KMime/KMimeMessage>
 #include <QDateTime>
-#include <kmime/kmime_message.h>
 
 #include <QRegularExpression>
 #include <QString>
@@ -37,7 +37,7 @@ namespace NoteUtils
 
 #define ENCODING "utf-8"
 
-class Q_DECL_HIDDEN Attachment::AttachmentPrivate
+class AttachmentPrivate
 {
 public:
     AttachmentPrivate(const QUrl &url, const QString &mimetype)
@@ -66,17 +66,17 @@ public:
 };
 
 Attachment::Attachment()
-    : d_ptr(new Attachment::AttachmentPrivate(QUrl(), QString()))
+    : d_ptr(new AttachmentPrivate(QUrl(), QString()))
 {
 }
 
 Attachment::Attachment(const QUrl &url, const QString &mimetype)
-    : d_ptr(new Attachment::AttachmentPrivate(url, mimetype))
+    : d_ptr(new AttachmentPrivate(url, mimetype))
 {
 }
 
 Attachment::Attachment(const QByteArray &data, const QString &mimetype)
-    : d_ptr(new Attachment::AttachmentPrivate(data, mimetype))
+    : d_ptr(new AttachmentPrivate(data, mimetype))
 {
 }
 
@@ -85,10 +85,7 @@ Attachment::Attachment(const Attachment &other)
 {
 }
 
-Attachment::~Attachment()
-{
-    delete d_ptr;
-}
+Attachment::~Attachment() = default;
 
 bool Attachment::operator==(const Attachment &a) const
 {
@@ -160,7 +157,7 @@ QString Attachment::label() const
     return d->mLabel;
 }
 
-class Q_DECL_HIDDEN NoteMessageWrapper::NoteMessageWrapperPrivate
+class NoteMessageWrapperPrivate
 {
 public:
     NoteMessageWrapperPrivate()
@@ -188,11 +185,11 @@ public:
     QDateTime lastModifiedDate;
     QMap<QString, QString> custom;
     QVector<Attachment> attachments;
-    Classification classification = Public;
+    NoteMessageWrapper::Classification classification = NoteMessageWrapper::Public;
     Qt::TextFormat textFormat = Qt::PlainText;
 };
 
-void NoteMessageWrapper::NoteMessageWrapperPrivate::readMimeMessage(const KMime::MessagePtr &msg)
+void NoteMessageWrapperPrivate::readMimeMessage(const KMime::MessagePtr &msg)
 {
     if (!msg.data()) {
         qCWarning(AKONADINOTES_LOG) << "Empty message";
@@ -222,9 +219,9 @@ void NoteMessageWrapper::NoteMessageWrapperPrivate::readMimeMessage(const KMime:
     if (KMime::Headers::Base *classificationHeader = msg->headerByType(X_NOTES_CLASSIFICATION_HEADER)) {
         const QString &c = classificationHeader->asUnicodeString();
         if (c == CLASSIFICATION_PRIVATE) {
-            classification = Private;
+            classification = NoteMessageWrapper::Private;
         } else if (c == CLASSIFICATION_CONFIDENTIAL) {
-            classification = Confidential;
+            classification = NoteMessageWrapper::Confidential;
         }
     }
 
@@ -254,7 +251,8 @@ QDomDocument createXMLDocument()
 QDomDocument loadDocument(KMime::Content *part)
 {
     QString errorMsg;
-    int errorLine, errorColumn;
+    int errorLine;
+    int errorColumn;
     QDomDocument document;
     bool ok = document.setContent(part->body(), &errorMsg, &errorLine, &errorColumn);
     if (!ok) {
@@ -265,7 +263,7 @@ QDomDocument loadDocument(KMime::Content *part)
     return document;
 }
 
-KMime::Content *NoteMessageWrapper::NoteMessageWrapperPrivate::createCustomPart() const
+KMime::Content *NoteMessageWrapperPrivate::createCustomPart() const
 {
     KMime::Content *content = new KMime::Content();
     auto header = new KMime::Headers::Generic(X_NOTES_CONTENTTYPE_HEADER);
@@ -286,7 +284,7 @@ KMime::Content *NoteMessageWrapper::NoteMessageWrapperPrivate::createCustomPart(
     return content;
 }
 
-void NoteMessageWrapper::NoteMessageWrapperPrivate::parseCustomPart(KMime::Content *part)
+void NoteMessageWrapperPrivate::parseCustomPart(KMime::Content *part)
 {
     QDomDocument document = loadDocument(part);
     if (document.isNull()) {
@@ -309,7 +307,7 @@ void NoteMessageWrapper::NoteMessageWrapperPrivate::parseCustomPart(KMime::Conte
     }
 }
 
-KMime::Content *NoteMessageWrapper::NoteMessageWrapperPrivate::createAttachmentPart(const Attachment &a) const
+KMime::Content *NoteMessageWrapperPrivate::createAttachmentPart(const Attachment &a) const
 {
     KMime::Content *content = new KMime::Content();
     auto header = new KMime::Headers::Generic(X_NOTES_CONTENTTYPE_HEADER);
@@ -340,7 +338,7 @@ KMime::Content *NoteMessageWrapper::NoteMessageWrapperPrivate::createAttachmentP
     return content;
 }
 
-void NoteMessageWrapper::NoteMessageWrapperPrivate::parseAttachmentPart(KMime::Content *part)
+void NoteMessageWrapperPrivate::parseAttachmentPart(KMime::Content *part)
 {
     QString label;
     if (KMime::Headers::Base *labelHeader = part->headerByType(X_NOTES_LABEL_HEADER)) {
@@ -369,10 +367,7 @@ NoteMessageWrapper::NoteMessageWrapper(const KMime::MessagePtr &msg)
 {
 }
 
-NoteMessageWrapper::~NoteMessageWrapper()
-{
-    delete d_ptr;
-}
+NoteMessageWrapper::~NoteMessageWrapper() = default;
 
 KMime::MessagePtr NoteMessageWrapper::message() const
 {
