@@ -4,13 +4,15 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef NOTEUTILS_H
-#define NOTEUTILS_H
+#pragma once
 
 #include "akonadi-notes_export.h"
 
 #include <QMap>
 #include <QUrl>
+
+#include <memory>
+
 class QDateTime;
 class QString;
 
@@ -37,6 +39,8 @@ AKONADI_NOTES_EXPORT QString noteMimeType();
  */
 AKONADI_NOTES_EXPORT QString noteIconName();
 
+class AttachmentPrivate;
+
 /**
  * An attachment for a note
  * @since 4.9
@@ -87,7 +91,7 @@ public:
 
     /**
      * Set this to true if inline data provided via ctor
-     * is alredy base64 encoded. Default value is false.
+     * is already base64 encoded. Default value is false.
      *
      * @since 5.15
      */
@@ -117,12 +121,13 @@ public:
 
 private:
     //@cond PRIVATE
-    class AttachmentPrivate;
-    AttachmentPrivate *const d_ptr;
+    std::unique_ptr<AttachmentPrivate> const d_ptr;
     Q_DECLARE_PRIVATE(Attachment)
     //@endcond
 };
 
+class NoteMessageWrapperPrivate;
+
 /**
  * A convenience wrapper around KMime::MessagePtr for notes
  *
@@ -276,8 +281,7 @@ public:
 private:
     //@cond PRIVATE
     Q_DISABLE_COPY(NoteMessageWrapper)
-    class NoteMessageWrapperPrivate;
-    NoteMessageWrapperPrivate *const d_ptr;
+    std::unique_ptr<NoteMessageWrapperPrivate> const d_ptr;
     Q_DECLARE_PRIVATE(NoteMessageWrapper)
     //@endcond
 };
@@ -286,4 +290,3 @@ private:
 }
 
 Q_DECLARE_TYPEINFO(Akonadi::NoteUtils::Attachment, Q_MOVABLE_TYPE);
-#endif
